@@ -2,7 +2,7 @@
     
     peakmeter.cpp - simple audio meter plugin
     
-    Copyright (C) 2006-2007 Lars Luthman <lars.luthman@gmail.com>
+    Copyright (C) 2006-2007 Lars Luthman <mail@larsluthman.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,8 @@
 
 #include <cmath>
 
-#include "lv2plugin.hpp"
+#include <lv2plugin.hpp>
+
 #include "peakmeter.peg"
 
 
