@@ -2,7 +2,7 @@
     
     rudolf556.cpp - Simple drum machine plugin
     
-    Copyright (C) 2008 Lars Luthman <lars.luthman@gmail.com>
+    Copyright (C) 2008 Lars Luthman <mail@larsluthman.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 
 #include <samplerate.h>
 #include <sndfile.h>
+#include <lv2synth.hpp>
 
-#include "lv2synth.hpp"
 #include "rudolf556.peg"
 
 
