@@ -2,7 +2,7 @@
     
     lv2host.cpp - Simple LV2 plugin loader for Elven
     
-    Copyright (C) 2006-2007 Lars Luthman <lars.luthman@gmail.com>
+    Copyright (C) 2006-2007 Lars Luthman <mail@larsluthman.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -133,10 +133,10 @@ void LV2Host::run_main() {
     DBG2("Got notification from realtime thread about port change");
     while (!sem_trywait(&m_notification_sem));
     for (unsigned i = 0; i < m_ports.size(); ++i) {
-      if (m_ports[i].notify && m_ports[i].direction == OutputPort) {
-	// XXX this should only happen if the port value has actually changed
-	DBG2("Sending port event for output port "<<i);
-	signal_port_event(i, sizeof(float), 0, &m_ports[i].old_value);
+      if (m_ports[i].notify) {
+        // XXX this should only happen if the port value has actually changed
+        DBG2("Sending port event for output port "<<i);
+        signal_port_event(i, sizeof(float), 0, &m_ports[i].old_value);
       }
     }
   }
@@ -1137,11 +1137,13 @@ uint32_t LV2Host::uri_to_id(LV2_URI_Map_Callback_Data callback_data,
 
 uint32_t LV2Host::event_ref(LV2_Event_Callback_Data, LV2_Event* ev) {
   DBG2("Reference count for event "<<ev<<" increased");
+  return 0;
 }
 
 
 uint32_t LV2Host::event_unref(LV2_Event_Callback_Data, LV2_Event* ev) {
   DBG2("Reference count for event "<<ev<<" decreased");
+  return 0;
 }
 
 
