@@ -2,7 +2,7 @@
     
     main.cpp - Main source file for the LV2 host Elven
     
-    Copyright (C) 2006-2007 Lars Luthman <lars.luthman@gmail.com>
+    Copyright (C) 2006-2007 Lars Luthman <mail@larsluthman.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,12 +34,11 @@
 
 #include <jack/jack.h>
 #include <jack/midiport.h>
-#include <lash/lash.h>
 #include <gtkmm.h>
+#include <lv2_event_helpers.h>
 
 #include "lv2guihost.hpp"
 #include "lv2host.hpp"
-#include <lv2_event_helpers.h>
 #include "debug.hpp"
 #include "midiutils.hpp"
 
@@ -50,7 +49,6 @@ using namespace sigc;
 
 vector<jack_port_t*> jack_ports;
 jack_client_t* jack_client;
-lash_client_t* lash_client;
 bool still_running;
 
 
@@ -227,24 +225,6 @@ string unescape_space(const string& str) {
 }
 
 
-bool init_lash(int argc, char** argv, const char* jackname) {
-  DBG2("Initialising LASH client");
-  lash_client = lash_init(lash_extract_args(&argc, &argv), "elven", 
-                          LASH_Config_File, LASH_PROTOCOL(2, 0));
-  
-  if (lash_client) {
-    lash_event_t* event = lash_event_new_with_type(LASH_Client_Name);
-    lash_event_set_string(event, "Elven");
-    lash_send_event(lash_client, event);      
-    lash_jack_client_name(lash_client, jackname);
-  }
-  else
-    DBG0("Could not initialise LASH!");
-  
-  return (lash_client != 0);
-}
-
-
 /** Translate from an LV2 MIDI buffer to a JACK MIDI buffer. */
 void lv2midi2jackmidi(LV2Port& port, jack_port_t* jack_port, 
                       jack_nframes_t nframes) {
@@ -335,6 +315,7 @@ void jackmidi2lv2midi(jack_port_t* jack_port, LV2Port& port,
       float& min = host.get_ports()[port].min_value;
       float& max = host.get_ports()[port].max_value;
       *pbuf = min + (max - min) * input_event.buffer[2] / 127.0;
+      DBG3("Mapped CC event to port "<<port);
       // XXX notify the main thread somehow
       //host.queue_control(port, *pbuf, false);
     }
@@ -410,94 +391,6 @@ void thread_init(void*) {
 }
 
 
-void check_lash_events(LV2Host& lv2h) {
-
-  lash_event_t* event;
-  while ((event = lash_get_event(lash_client))) {
-    
-    // save
-    if (lash_event_get_type(event) == LASH_Save_File) {
-      
-      ofstream of((string(lash_event_get_string(event)) + 
-		   "/lv2host").c_str());
-      const std::vector<LV2Port>& ports = lv2h.get_ports();
-      for (unsigned i = 0; i < ports.size(); ++i) {
-	if (ports[i].type == ControlType && ports[i].direction == InputPort)
-	  of<<"control "<<i<<" "<<ports[i].value<<endl;
-      }
-      
-      LV2SR_File** files;
-      if (lv2h.save(lash_event_get_string(event), &files)) {
-	for ( ; *files; ++files) {
-	  of<<"file "<<(*files)->must_copy<<" "
-	    <<(*files)->name<<" "<<(*files)->path<<endl;
-	  free((*files)->name);
-	  free((*files)->path);
-	  free(*files);
-	}
-      }
-      
-      of.close();
-      
-      lash_send_event(lash_client, 
-		      lash_event_new_with_type(LASH_Save_File));
-    }
-    
-    // restore
-    else if (lash_event_get_type(event) == LASH_Restore_File) {
-      
-      cerr<<"Got a LASH restore event"<<endl;
-      
-      ifstream ifs((string(lash_event_get_string(event)) + 
-		    "/lv2host").c_str());
-      
-      vector<LV2SR_File*> file_vector;
-      
-      while (ifs) {
-	string word;
-	ifs>>word;
-	
-	if (word == "control") {
-	  unsigned long port;
-	  float value;
-	  ifs>>port>>value;
-	  lv2h.set_control(port, value);
-	}
-	
-	else if (word == "file") {
-	  uint32_t must_copy;
-	  string name;
-	  string path;
-	  ifs>>must_copy>>name>>path;
-	  LV2SR_File* file=static_cast<LV2SR_File*>(malloc(sizeof(LV2SR_File)));
-	  file->must_copy = must_copy;
-	  file->name = strdup(name.c_str());
-	  file->path = strdup(path.c_str());
-	  file_vector.push_back(file);
-	}
-        
-      }
-      
-      if (file_vector.size() > 0) {
-	lv2h.restore(const_cast<const LV2SR_File**>(&file_vector[0]));
-	for (size_t i = 0; i < file_vector.size(); ++i)
-	  free(file_vector[i]);
-      }
-      
-      lash_send_event(lash_client,
-		      lash_event_new_with_type(LASH_Restore_File));
-    }
-    
-    // quit
-    else if (lash_event_get_type(event) == LASH_Quit)
-      still_running = false;
-    
-    lash_event_destroy(event);
-  }
-      
-}
-
-
 void sigchild(int signal) {
   DBG2("Child process terminated");
   if (signal == SIGCHLD)
@@ -508,7 +401,7 @@ void sigchild(int signal) {
 void print_version() {
   clog<<"Elven is an (E)xperimental (LV)2 (E)xecution e(N)vironment.\n"
       <<"Version " VERSION 
-      <<", (C) 2006-2007 Lars Luthman <lars.luthman@gmail.com>\n"
+      <<", (C) 2006-2007 Lars Luthman <mail@larsluthman.net>\n"
       <<"Released under the GNU General Public License, version 3 or later.\n"
       <<endl;
 }
@@ -629,11 +522,6 @@ int main(int argc, char** argv) {
     
     DBG2("Default MIDI port: "<<lv2h.get_default_midi_port());
     
-    if (!init_lash(argc, argv, jack_get_client_name(jack_client))) {
-      DBG0("Could not initialise LASH");
-      return -1;
-    }
-    
     // initialise port buffers
     for (size_t p = 0; p < lv2h.get_ports().size(); ++p) {
       jack_port_t* port = 0;
@@ -735,8 +623,6 @@ int main(int argc, char** argv) {
     autoconnect(jack_client);
     
     // wait until we are killed
-    slot<void> lash_slot = bind(&check_lash_events, ref(lv2h));
-    Glib::signal_timeout().connect(bind_return(lash_slot, true), 100);
     Glib::signal_timeout().
       connect(bind_return(mem_fun(lv2h, &LV2Host::run_main), true), 10);
     if (win) {
